@@ -6,24 +6,25 @@ all.Amidihcrss<-function(){
      cat("--------------------------------------------------------------\n")  
      cat("\n")
      note_for_close_window()
-     AmidihcrSSpar<-data.frame(parameter=c("Gender","age (yr)","ht (cm)","CHF","smoke","D (mg)","tau (hr)","c (mg/L)"),value=c(0))                                           
+     AmidihcrSSpar<-data.frame(parameter=c("Gender","age (yr)","ht (cm)","CHF","smoke","D (mg)","tau (hr)","c (mg/L)"),
+                               value=c(1,65,167,0,1,600,12,7.34))
      AmidihcrSSpar<-edit(AmidihcrSSpar)                                                                                                                                          
 ##     AmidihcrSSpar<-ycheck(AmidihcrSSpar) 
-     cat("\n")                                                                                                                                        
+     cat("\n")
+     cat("\n Input data are as follows:\n")
+     cat(" --------------------------\n")
+     show(AmidihcrSSpar);cat("\n\n")
      Amidihcr.ss(AmidihcrSSpar[8,2],AmidihcrSSpar[7,2],AmidihcrSSpar[6,2],AmidihcrSSpar[3,2],AmidihcrSSpar[2,2],AmidihcrSSpar[5,2],AmidihcrSSpar[1,2],AmidihcrSSpar[4,2]) 
      note_for_convergence_plots()
-     convergence_plots_sep()
+     ### convergence_plots_sep()
      cat("-------------------------------------------------------------\n")
      cat("    --Aminophylline dihydrous CR input data information--    \n")
      note_for_Thecr_output()
      cat("-------------------------------------------------------------\n")
-     show(samplesStats("*"))
+     ### show(samplesStats("*"))
      cat("\n") 
      C<-TheCRcpr(0.8,AmidihcrSSpar[6,2],AmidihcrSSpar[7,2])
-     sim<-matrix(C[1 ,1])
-     coutput<-data.frame(sim)
-     colnames(coutput)<-list("Css_pr (mg/L)")     
-     show(coutput)
+     coutput<-data.frame(conc=c("Css_obs","Css_pr"),value=c(AmidihcrSSpar[8,2],C))
      cat("\n")   
-     Amidihcr.more()              
+     Amidihcr.more()
 }
\ No newline at end of file
