@@ -9,13 +9,13 @@ all.Digss<-function(){
      cat("\n")
      Dig.ss(DigSSpar[7,2],DigSSpar[6,2],DigSSpar[5,2],DigSSpar[4,2],DigSSpar[3,2],DigSSpar[2,2],DigSSpar[1,2])
      note_for_convergence_plots()
-     convergence_plots_sep()
+     ### convergence_plots_sep()
      note_for_Dig_output()
-     show(samplesStats("*"))
+     ### show(samplesStats("*"))
      cat("\n") 
      C<-Digcpr(DigSSpar[5,2],DigSSpar[6,2])
-     sim<-matrix(C[1 ,1])
-     coutput<-data.frame(sim)
+     ### sim<-matrix(C[1 ,1])
+     coutput<-data.frame(C)
      colnames(coutput)<-list("Cmss_pr (ng/mL)")
      show(coutput)
      cat("\n") 
