@@ -6,8 +6,13 @@ all.Oxtirsm<-function(){
      cat("--------------------------------------------------------\n") 
      cat("\n")
      note_for_close_window()
-     OxtirSMMpar<-data.frame(parameter=c("Gender","age (yr)","ht (cm)","CHF","smoke","D (mg)","tau (hr)"),value=c(0))
+     OxtirSMMpar<-data.frame(parameter=c("Gender","age (yr)","ht (cm)","CHF","smoke","D (mg)","tau (hr)"),
+                             value=c(1,67,176,1,0,300,8))
      OxtirSMMpar<-edit(OxtirSMMpar)
+     cat("\n")
+     cat("\n Input data are as follows:\n")
+     cat(" --------------------------\n")
+     show(OxtirSMMpar);cat("\n\n")
 ##     OxtirSMMpar<-ycheck(OxtirSMMpar)
      cat("\n")
      cat("---------------------------------------------------------\n")
@@ -16,31 +21,35 @@ all.Oxtirsm<-function(){
      cat("---------------------------------------------------------\n")
      cat("\n")
      note_for_close_window()
-     OxtirSMpar<-data.frame(ts=c(0),conc=c(0))                                                                                                                             
+     OxtirSMpar<-data.frame(ts=c(4,8),conc=c(8.56,5.67))                                                                                                                             
      OxtirSMpar<-edit(OxtirSMpar)                                               
-     OxtirSMpar<-mscheck(OxtirSMpar)                                           
-     cat("\n")
+     ### OxtirSMpar<-mscheck(OxtirSMpar)                                           
+     cat("\n");show(OxtirSMpar);cat("\n\n")
      Oxtir.sm(length(OxtirSMpar$ts),OxtirSMpar$conc,OxtirSMpar$ts,OxtirSMMpar[7,2],OxtirSMMpar[6,2],OxtirSMMpar[3,2],OxtirSMMpar[2,2],OxtirSMMpar[5,2],OxtirSMMpar[1,2],OxtirSMMpar[4,2])
      note_for_convergence_plots()
-     convergence_plots_sep()
+     ### convergence_plots_sep()
      cat("------------------------------------------------------------------\n")
      cat("    --Oxtriphylline IR output data information--                  \n")
      note_for_Theirsm_output()
      cat("------------------------------------------------------------------\n")
-     show(samplesStats("*"))
+     ### show(samplesStats("*"))
+     X <- read.table("params.csv",header=FALSE)
+     cl_F <- X[1,2]
+     v_F  <- X[2,2]
      cat("\n")
-     r=log(1.85-(samplesStats("cl_F")/samplesStats("v_F")))/(1.85-(samplesStats("cl_F")/samplesStats("v_F")))
-     C<-TheIRsscpr(0.65,OxtirSMMpar[6,2],OxtirSMMpar[7,2],r)
-     sim<-matrix(C[1 ,1])
-     coutput<-data.frame(sim)
-     colnames(coutput)<-list("Cpss_pr (mg/L)")
-     output1<-coutput
-     show(coutput)
-     C<-TheIRsscpr(0.65,OxtirSMMpar[6,2],OxtirSMMpar[7,2],OxtirSMMpar[7,2])
-     sim<-matrix(C[1 ,1])
-     coutput<-data.frame(sim)
-     colnames(coutput)<-list("Ctss_pr (mg/L)")
-     output2<-coutput
+     Tmax=log(1.85-(cl_F/v_F))/(1.85-(cl_F/v_F))
+     C1<-TheIRsscpr(0.65,OxtirSMMpar[6,2],OxtirSMMpar[7,2],Tmax)
+     C2<-TheIRsscpr(0.65,OxtirSMMpar[6,2],OxtirSMMpar[7,2],OxtirSMMpar[7,2])
+     ### sim<-matrix(C[1 ,1])
+     ### show obs. and calc. conc. here  -YJ
+     cat("\n\n")
+     for(i in 1:length(OxtirSMpar$ts)){
+         Cx<-TheIRsscpr(0.8,OxtirSMMpar[6,2],OxtirSMMpar[7,2],OxtirSMpar$ts[i]) 
+         coutput<-data.frame(conc=c("obs. conc.","calc. conc."), values=c(OxtirSMpar$conc[i],Cx))
+         cat("--- Theophylline plasma conc. (mg/L) at Time =",OxtirSMpar$ts[i],"---\n")
+         show(coutput);cat("\n")
+     }
+     coutput<-data.frame(conc=c("Cpss_pr (mg/L)","Ctss_pr (mg/L)"),calc=c(C1,C2))
      show(coutput)     
      cat("\n")   
      Oxtir.more()                                    
