@@ -6,8 +6,10 @@ all.Theirsm<-function(){
      cat("-----------------------------------------------------\n")
      cat("\n")
      note_for_close_window()
-     TheirSMMpar<-data.frame(parameter=c("Gender","age (yr)","ht (cm)","CHF","smoke","D (mg)","tau (hr)"),value=c(0))
+     TheirSMMpar<-data.frame(parameter=c("Gender","age (yr)","ht (cm)","CHF","smoke","D (mg)","tau (hr)"),
+                             value=c(1,67,176,1,0,300,8))
      TheirSMMpar<-edit(TheirSMMpar)
+     cat("\n");show(TheirSMMpar);cat("\n\n")
 ##     TheirSMMpar<-ycheck(TheirSMMpar)
      cat("\n")
      cat("--------------------------------------------------------\n")
@@ -16,31 +18,34 @@ all.Theirsm<-function(){
      cat("--------------------------------------------------------\n")
      cat("\n")
      note_for_close_window()
-     TheirSMpar<-data.frame(ts=c(0),conc=c(0))                                                                                                                                 
+     TheirSMpar<-data.frame(ts=c(4,8),conc=c(8.56,5.67))                                                                                                                                 
      TheirSMpar<-edit(TheirSMpar)                                               
-     TheirSMpar<-mscheck(TheirSMpar)                                            
-     cat("\n")
+     ### TheirSMpar<-mscheck(TheirSMpar)  ### this line must be deleted.  -YJ
+     cat("\n");show(TheirSMpar);cat("\n\n")
      Their.sm(length(TheirSMpar$ts),TheirSMpar$conc,TheirSMpar$ts,TheirSMMpar[7,2],TheirSMMpar[6,2],TheirSMMpar[3,2],TheirSMMpar[2,2],TheirSMMpar[5,2],TheirSMMpar[1,2],TheirSMMpar[4,2])
      note_for_convergence_plots()
-     convergence_plots_sep()
+     ### convergence_plots_sep()
      cat("-----------------------------------------------------------------\n")
      cat("    --Theophylline IR output data information--                  \n")
      note_for_Theirsm_output()
      cat("-----------------------------------------------------------------\n")
-     show(samplesStats("*"))
+     ### show(samplesStats("*"))
+     X <- read.table("params.csv",header=FALSE)
+     cl_F <- X[1,2]
+     v_F  <- X[2,2]
      cat("\n")
-     r=log(1.85-(samplesStats("cl_F")/samplesStats("v_F")))/(1.85-(samplesStats("cl_F")/samplesStats("v_F")))
-     C<-TheIRsscpr(1,TheirSMMpar[6,2],TheirSMMpar[7,2],r)
-     sim<-matrix(C[1 ,1])
-     coutput<-data.frame(sim)
-     colnames(coutput)<-list("Cpss_pr (mg/L)")
-     output1<-coutput
-     show(coutput) 
-     C<-TheIRsscpr(1,TheirSMMpar[6,2],TheirSMMpar[7,2],TheirSMMpar[7,2])
-     sim<-matrix(C[1 ,1])
-     coutput<-data.frame(sim)
-     colnames(coutput)<-list("Ctss_pr (mg/L)")
-     output2<-coutput
+     Tmax=log(1.85-(cl_F/v_F))/(1.85-(cl_F/v_F))
+     ### show obs. and calc. conc. here  -YJ
+     cat("\n\n")
+     for(i in 1:length(TheirSMpar$ts)){
+         Cx<-TheIRsscpr(0.85,TheirSMMpar[6,2],TheirSMMpar[7,2],TheirSMpar$ts[i]) 
+         coutput<-data.frame(conc=c("obs. conc.","calc. conc."), values=c(TheirSMpar$conc[i],Cx))
+         cat("--- Theophylline plasma conc. (mg/L) at Time =",TheirSMpar$ts[i],"---\n")
+         show(coutput);cat("\n")
+     }
+     C1<-TheIRsscpr(1,TheirSMMpar[6,2],TheirSMMpar[7,2],Tmax)
+     C2<-TheIRsscpr(1,TheirSMMpar[6,2],TheirSMMpar[7,2],TheirSMMpar[7,2])
+     coutput<-data.frame(conc=c("Cpss_pr (mg/L)","Ctss_pr (mg/L)"),calc=c(C2,C1))
      show(coutput)     
      cat("\n")     
      Their.more()                                 
