@@ -5,29 +5,37 @@ all.Vanss<-function(){
      note_for_close_window()
      VanSSpar<-data.frame(parameter=c("Gender","age (yr)","bw (kg)","Scr (mg/dL)","D (mg)","tau (hr)","tin (hr)","ts (hr)","c (mg/L)"),value=c(0))
      VanSSpar<-edit(VanSSpar)
+     cat("\n Input data are as follows:\n")
+     cat(" ----------------------------\n")
+     show(VanSSpar);cat("\n\n")
 ##     VanSSpar<-ycheck(VanSSpar)
      cat("\n")
      Van.ss(VanSSpar[9,2],VanSSpar[6,2],VanSSpar[8,2],VanSSpar[7,2],VanSSpar[5,2],VanSSpar[3,2],VanSSpar[4,2],VanSSpar[1,2],VanSSpar[2,2])
      note_for_convergence_plots()
-     convergence_plots_sep()
+     ### convergence_plots_sep()
      note_for_Vanss_output()
-     show(samplesStats("*"))
+     ### show(samplesStats("*"))
      cat("\n")
      C<-infcpr(VanSSpar[5,2],VanSSpar[7,2],VanSSpar[6,2],VanSSpar[8,2]+VanSSpar[7,2])
-     sim<-matrix(C[1 ,1])
-     coutput<-data.frame(sim)
+     ### sim<-matrix(C[1 ,1])
+     coutput<-data.frame(C)
      colnames(coutput)<-list("Cmss_pr (mg/L)")
      output1<-coutput
-     show(coutput)    
-     C<-infcpr(VanSSpar[5,2],VanSSpar[7,2],VanSSpar[6,2],VanSSpar[6,2])/(exp(-(samplesStats("cl")/samplesStats("v"))*(VanSSpar[6,2]-(VanSSpar[7,2]+1))))
-     sim<-matrix(C[1 ,1])
-     coutput<-data.frame(sim)
+     show(coutput)
+     ### read from saved .cvs -YJ
+     X <- read.table("params.csv",header=FALSE)
+     cl <- X[1,2]
+     v  <- X[2,2]
+     ###
+     C<-infcpr(VanSSpar[5,2],VanSSpar[7,2],VanSSpar[6,2],VanSSpar[6,2])/(exp(-(cl/v)*(VanSSpar[6,2]-(VanSSpar[7,2]+1))))
+     ### sim<-matrix(C[1 ,1])
+     coutput<-data.frame(C)
      colnames(coutput)<-list("Cpss_pr (mg/L)")
      output2<-coutput
      show(coutput)
      C<-infcpr(VanSSpar[5,2],VanSSpar[7,2],VanSSpar[6,2],VanSSpar[6,2])
-     sim<-matrix(C[1 ,1])
-     coutput<-data.frame(sim)
+     ### sim<-matrix(C[1 ,1])
+     coutput<-data.frame(C)
      colnames(coutput)<-list("Ctss_pr (mg/L)")
      output3<-coutput
      show(coutput)     
