@@ -7,7 +7,8 @@ packageStartupMessage("
 
 ************************--> tdm <--********************************
            An R Tool for Therapeutic Drug Monitoring               
-                          v 2.2.6                                   
+                          v 3.0.0                                 
+  DISCLAIMER:                        
   TDM is created for your own personal uses and testing purposes.  
   TDM shall be used as a guide or a decision support tool only.    
   Medical decisions should NOT be solely based on the results of   
@@ -18,13 +19,7 @@ packageStartupMessage("
   ** Please type 'run()' to get started or 
      type 'demo(phenytoin)' for the test runs of estimation
      phenytoin PK parameters.
-     type 'demo(warfarin)' for the test runs of estimation
-     warfarin PK/PD parameters.
 
-ps. Please install openBUGS from http://www.openbugs.info/ 
-    based on your platform (linux or Windows) before running 
-    this package.
 *******************************************************************")
-
 }
 
